continuous_interaction: Simulated experiment whose effect varies with a continuous...

continuous_interactionR Documentation

Simulated experiment whose effect varies with a continuous covariate

Description

The treatment effect is a nonlinear function of X, which makes this dataset useful for showing conditional average treatment effects. Subjects were also sampled with probability related to X, so the sample is not a simple random sample of the population that generated it.

Usage

continuous_interaction

Format

continuous_interaction

A tibble with 1189 rows and 10 columns:

ID

Subject identifier

noise

Unobserved subject-level shock

X

Continuous pretreatment covariate

Y_Z_1, Y_Z_0

Continuous potential outcomes under treatment and control

S_inclusion_prob

Probability the subject was sampled, which increases in X

Z

Random assignment, 1 for treatment and 0 for control

Z_cond_prob

Probability of the assigned condition, 0.5 throughout

Y

Revealed outcome

condition

Z labelled "Treatment" and "Control"

\Sexpr[results=rd]{tools:::Rd_expr_doi("10.7910/DVN/VE6VSR")}

See Also

Other Data: attrition_experiment, blocked_experiment, clustered_experiment, covariate_adjustment, noncompliance_experiment, patriot_act, two_arm_trial


vayr documentation built on Aug. 22, 2026, 1:08 a.m.