patriot_act: Original and Replication data for the Patriot Act experiment...

patriot_actR Documentation

Original and Replication data for the Patriot Act experiment described in Persuasion in Parallel

Description

Original and Replication data for the Patriot Act experiment described in Persuasion in Parallel

Usage

patriot_act

Format

patriot_act

A tibble with 2062 rows and 4 columns:

sample_label

The original study (Chong and Druckman (2011) or the Mechanical Turk replication)

pid_3

Subject partisanship (limited to Republicans and Democracts, including leaners)

T1_content

Content of assigned treatment condition: pro-Patriot act statements, anti-Patriot act statements, or a control

PA_support

Post-treatment support for the Patriot Act on a 1 to 7 Likert scale

\Sexpr[results=rd]{tools:::Rd_expr_doi("10.7910/DVN/I9GSKI")}

See Also

Other Data: attrition_experiment, blocked_experiment, clustered_experiment, continuous_interaction, covariate_adjustment, noncompliance_experiment, two_arm_trial


vayr documentation built on Aug. 22, 2026, 1:08 a.m.