| vayr | R Documentation |
Position adjustments for 'ggplot2' to implement "visualize as you randomize" principles, which can be especially useful when plotting experimental data.
The 'vayr' package provides 'ggplot2' extensions that foster "visualize as you randomize" principles. These principles should guide the visualization of experimental data. Thus far, the package includes position adjustments that avoid over-plotting, which helps organize "data-space." The principles are set out in Coppock (2021) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1017/9781108777919.022")}.
Maintainer: Alexander Coppock acoppock@gmail.com (ORCID) [copyright holder]
Authors:
Alexander Coppock acoppock@gmail.com (ORCID) [copyright holder]
Other contributors:
Elias Hyde eliasworrallhyde@gmail.com [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.