| continuous_interaction | R Documentation |
The treatment effect is a nonlinear function of X, which makes this dataset
useful for showing conditional average treatment effects. Subjects were also
sampled with probability related to X, so the sample is not a simple random
sample of the population that generated it.
continuous_interaction
continuous_interactionA tibble with 1189 rows and 10 columns:
Subject identifier
Unobserved subject-level shock
Continuous pretreatment covariate
Continuous potential outcomes under treatment and control
Probability the subject was sampled, which increases in X
Random assignment, 1 for treatment and 0 for control
Probability of the assigned condition, 0.5 throughout
Revealed outcome
Z labelled "Treatment" and "Control"
Other Data:
attrition_experiment,
blocked_experiment,
clustered_experiment,
covariate_adjustment,
noncompliance_experiment,
patriot_act,
two_arm_trial
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.