| patriot_act | R Documentation |
Original and Replication data for the Patriot Act experiment described in Persuasion in Parallel
patriot_act
patriot_actA tibble with 2062 rows and 4 columns:
The original study (Chong and Druckman (2011) or the Mechanical Turk replication)
Subject partisanship (limited to Republicans and Democracts, including leaners)
Content of assigned treatment condition: pro-Patriot act statements, anti-Patriot act statements, or a control
Post-treatment support for the Patriot Act on a 1 to 7 Likert scale
Other Data:
attrition_experiment,
blocked_experiment,
clustered_experiment,
continuous_interaction,
covariate_adjustment,
noncompliance_experiment,
two_arm_trial
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.